@@ -1,3 +1,4 @@
+# See: https://www.charset.org/utf-8
 BACKSLASH = 92
 QUOTE = 34
 OPEN_SQUARE = 91
@@ -7,3 +8,4 @@ CLOSE_CURLY = 125
 SPACE = 32
 TAB = 9
 NEWLINE = 10
+COMMA = 44
